@@ -81,12 +81,12 @@ options(
 
 if ALL_TASKS_LOADED:
     
-    options.paved.clean.patterns += ['*.pickle', 
-                                     '*.doctree', 
-                                     '*.gz' , 
-                                     'nosetests.xml', 
-                                     'sloccount.sc', 
-                                     '*.pdf','*.tex', 
+    options.paved.clean.patterns += ['*.pickle',
+                                     '*.doctree',
+                                     '*.gz' ,
+                                     'nosetests.xml',
+                                     'sloccount.sc',
+                                     '*.pdf', '*.tex',
                                      '*.png',
                                      ]
     
@@ -95,7 +95,14 @@ if ALL_TASKS_LOADED:
     
     
     @task
-    @needs('sloccount', 'html', 'pdf', 'sdist', 'nose')
+    @needs(
+           'clean',
+           'sloccount',
+           'html',
+           'pdf',
+           'sdist',
+           'nose',
+           )
     def alltest():
         'all tasks to check'
         pass
@@ -109,6 +116,46 @@ if ALL_TASKS_LOADED:
     @needs('sphinxcontrib.paverutils.pdf')
     def pdf():
         fpdf = list(path('docs/_build/latex').walkfiles('*.pdf'))[0]
-        d=path('docs/_build/html')
+        d = path('docs/_build/html')
         d.makedirs()
         fpdf.copy(d)
+
+
+    def install_test(installer):
+        import virtualenv
+        import tempfile
+        import textwrap
+        root = path(tempfile.mkdtemp(prefix=NAME + '_'))
+        print 'root=', root
+        script = root / 'start_virtualenv'
+        
+        txt = """
+        def after_install(options, home_dir):
+            assert not os.system('{installer} {NAME}')
+        """.format(
+                   NAME=NAME,
+                   installer=root / 'env' / 'bin' / installer,
+                   )
+        
+        script_text = virtualenv.create_bootstrap_script(textwrap.dedent(txt))
+        script.write_text(script_text)
+        script.chmod(0755)
+        sh('./start_virtualenv env --no-site-packages', cwd=root)
+
+    @task
+    def pypi_pip():
+        install_test('pip install')
+
+    @task
+    def pypi_easy_install():
+        install_test('easy_install')
+        
+    @task
+    @needs(
+           'pypi_easy_install',
+           'pypi_pip', 
+           )
+    def pypi():
+        pass
+        
+        
\ No newline at end of file
